Chromium Code Reviews
chromiumcodereview-hr@appspot.gserviceaccount.com (chromiumcodereview-hr) | Please choose your nickname with Settings | Help | Chromium Project | Gerrit Changes | Sign out
(418)

Unified Diff: services/ui/display/screen_manager.h

Issue 2645093003: [WIP] ScreenManager: Add an external window mode (Closed)
Patch Set: Created 3 years, 11 months ago
Use n/p to move between diff chunks; N/P to move between comments. Draft comments are only viewable by you.
Jump to:
View side-by-side diff with in-line comments
Download patch
Index: services/ui/display/screen_manager.h
diff --git a/services/ui/display/screen_manager.h b/services/ui/display/screen_manager.h
index 3a0679cb085f2d68b0815ef6c2fac2c31287fe11..794cf2705894a3726e1f1ba57e9e3e347af1ee6f 100644
--- a/services/ui/display/screen_manager.h
+++ b/services/ui/display/screen_manager.h
@@ -20,6 +20,11 @@ namespace display {
// attached physical displays.
class ScreenManager {
public:
+ enum WindowMode {
+ WINDOW_MODE_EXTERNAL,
rjkroege 2017/01/23 21:19:43 We've emailed enough to know what these mean but I
fwang 2017/01/24 17:11:51 Done.
+ WINDOW_MODE_INTERNAL,
+ };
+
ScreenManager();
virtual ~ScreenManager();
@@ -30,12 +35,14 @@ class ScreenManager {
// Registers Mojo interfaces provided.
virtual void AddInterfaces(service_manager::InterfaceRegistry* registry) = 0;
- // Triggers initial display configuration to start. On device this will
- // configuration the connected displays. Off device this will create one or
- // more fake displays and pretend to configure them. A non-null |delegate|
- // must be provided that will receive notifications when displays are added,
- // removed or modified.
- virtual void Init(ScreenManagerDelegate* delegate) = 0;
+ // If |window_mode| == WINDOW_MODE_EXTERNAL, no initial displays are created
+ // or initialized. Otherwise, triggers initial display configuration to
+ // start. On device this will configure the connected displays. Off device
+ // this will create one or more fake displays and pretend to configure them. A
+ // non-null |delegate| must be provided that will receive notifications when
+ // displays are added, removed or modified.
rjkroege 2017/01/23 21:19:43 Does external mode need a delegate? I don't rememb
fwang 2017/01/24 17:11:51 Mmh, code in screen manager seems to assume the de
+ virtual void Init(ScreenManagerDelegate* delegate,
+ WindowMode window_mode) = 0;
// Handle requests from the platform to close a display.
virtual void RequestCloseDisplay(int64_t display_id) = 0;
« no previous file with comments | « no previous file | services/ui/display/screen_manager_ozone.h » ('j') | services/ui/display/screen_manager_ozone.h » ('J')

Powered by Google App Engine
This is Rietveld 408576698